@@ -16,11 +16,11 @@
 ############################################################################
 
 # Dynamically assigned attributes
-ATTR_EXECUTE_IN_THREAD = 'execute_in_thread'
-ATTR_COMMAND_TYPE = 'command'
-ATTR_FEATURE_TYPE = 'feature'
-ATTR_REGISTERED_NAME = 'reg_name'
-ATTR_REGISTERED_TYPE = 'reg_type'
+ATTR_EXECUTE_IN_THREAD = "execute_in_thread"
+ATTR_COMMAND_TYPE = "command"
+ATTR_FEATURE_TYPE = "feature"
+ATTR_REGISTERED_NAME = "reg_name"
+ATTR_REGISTERED_TYPE = "reg_type"
 
 # Parameters
-PARAM_LS = 'ls'
+PARAM_LS = "ls"
